@@ -22,20 +22,21 @@
 #include "value.h"
 #include "analitzautils.h"
 #include "operations.h"
+#include "analyzer.h"
 
 using namespace Analitza;
 
 // static QDebug operator<<(QDebug dbg, const Object* c)
 // {
 // 	dbg.nospace() << (c ? c->toString() : "<null>");
-// 
+//
 // 	return dbg.space();
 // }
-// 
+//
 // static QDebug operator<<(QDebug dbg, const Monomial &c)
 // {
 // 	dbg.nospace() << "(" << c.first << ", " << c.second << ")";
-// 
+//
 // 	return dbg.space();
 // }
 
@@ -53,6 +54,15 @@ static Object* negateObject(Object* o)
 	}
 }
 
+static Object* simpExpression(Object* o)
+{
+	Analyzer a;
+	a.setExpression(Expression(o));
+	a.simplify();
+	Expression ret = a.expression();
+	return ret.takeTree();
+}
+
 bool Monomial::isScalar(const Object* o)
 {
 	return o->type()==Object::value || (o->type()==Object::vector && !AnalitzaUtils::hasVars(o));
@@ -263,11 +273,11 @@ void Polynomial::simpScalars(bool firstValue)
 	Object *value=0;
 	if(!firstValue && m_operator==Operator::minus && !m_scalars.isEmpty())
 		m_scalars.first() = negateObject(m_scalars.first());
-	
+
 	for(QList<Object*>::const_iterator i=m_scalars.constBegin(); i!=m_scalars.constEnd(); ++i) {
 		bool d=false;
 		
-		Object* aux = *i;
+		Object* aux = simpExpression(*i);
 		if(value) {
 			QString* err=0;
 			value=Operations::reduce(m_operator.operatorType(), value, aux, &err);
